# Published Opinions

Published Opinions of the appellate courts are opinions certified for publication or ordered published and may be cited or relied on by courts and parties.

- Official Reports Opinions (Searchable 1850-Present) are the searchable, citable, published opinions that reflect postfiling corrections. This no-fee service is provided by LexisNexis.

- Slip Opinions are as-filed versions of opinions. Slip opinions certified for publication do not reflect enhancement, editing and correction for the Official Reports.

Supreme Court slip opinions are posted immediately on filing at 10:00 a.m. on Mondays and Thursdays. Court of Appeal slip opinions are posted throughout the day as soon after filing as possible.

Use the list below to select the slip opinions certified for publication, or ordered published, that you want to view and click on the "view" button to activate your selection.

Date Posted | Docket #/ File Format | Description
--- | --- | ---
Jul 17 2013 | H038353 [PDF] [DOC] | Fortner v. Super. Ct. 6/18/13 CA6 Case Details
Jul 17 2013 | H038349 [PDF] [DOC] | P. v. Pirali 7/17/13 CA6 Case Details
Jul 16 2013 | H038338 [PDF] [DOC] | May v. City of Milpitas 7/16/13 CA6 Case Details
Jul 12 2013 | H038734 [PDF] [DOC] | Diamond v. Super. Ct. 6/18/13 CA6 Case Details
Jul 11 2013 | H038109 [PDF] [DOC] | P. v. Barclay 7/11/13 CA6 Case Details
Jun 25 2013 | H037599 [PDF] [DOC] | Save Panoche Valley v. San Benito Cty. 6/25/13 CA6 Case Details
Jun 21 2013 | H038640 [PDF] [DOC] | In re M.P. 6/21/13 CA6 Case Details
Jun 18 2013 | H037245 [PDF] [DOC] | P. v. Fong 6/18/13 CA6 Case Details
Jun 06 2013 | H038563 [PDF] [DOC] | Cal Building Indus. etc. v. City of San Jose 6/6/13 CA6 Case Details
Jun 04 2013 | H037271 [PDF] [DOC] | Brown v. Super. Ct. 6/4/13 CA6 Case Details
May 23 2013 | H037923 [PDF] [DOC] | P. v. Scott 5/23/13 CA6 Case Details
May 16 2013 | H038971 [PDF] [DOC] | Silicon Valley Taxpayers v. Garner 5/16/13 CA6 Case Details
May 16 2013 | H037804 [PDF] [DOC] | Negri v. Koning & Assoc. 5/16/13 CA6 Case Details
May 15 2013 | H038784 [PDF] [DOC] | Bd. of Trustees Stanford University v. Ham 5/15/13 CA6 Case Details
May 07 2013 | H036977 [PDF] [DOC] | P. v. Tran 5/7/13 CA6 Case Details
Apr 29 2013 | H036764 [PDF] [DOC] | P. v. Tran 4/29/13 CA6 Case Details
Apr 26 2013 | H036475 [PDF] [DOC] | City of Monterey v. Carrnshimba 3/27/13 CA6 Case Details
Apr 25 2013 | H037530 [PDF] [DOC] | P. v. Mortimer 4/25/13 CA6 Case Details
Apr 25 2013 | H037195 [PDF] [DOC] | P. v. Fuquay 4/25/13 CA6 Case Details
Apr 23 2013 | H037207 [PDF] [DOC] | P. v. Blackburn 4/23/13 CA6 Case Details
Mar 29 2013 | H036974 [PDF] [DOC] | P. v. Rivas 3/29/13 CA6 Case Details